





* Code to produce appendix graphs. 
* Note that the graphs are produced independently in Stata.
* R Code is included at the end to generate overlapping graphs.
* This code can also be modified to reproduce the main figures
* from the manuscript.
* Also note that the last three or so lines of the Stata part of the
* do file may have to be run again manually. For some reason Stata will not 
* always clear the file in response to the "clear" command.

clear all

use "Replication data.dta"

set seed 0210
set more off, perm  

* Squared Polity variables

estsimp nbreg F.hrosecloc_merge physint con_physint conphysXphys polity20 polity_square orgrights kof_ogi S_all latincarib durable lngdppercap lnpop civilconflict  NGOtargetGTDfilled dictHROngostateviolent  lnreport conhrosecloc lnhrfilled yr12-yr24 if western==0, robust

preserve

setx mean //first set all to means, then modifiy where needed (below)
setx civilconflict 0
setx latincarib 0 
setx dictHROngostateviolent 0
setx (yr12-yr24) 0
setx yr15 1
local a = 0
local b = (`a'^2)
setx polity20 (`a') polity_square (`b')
simqi, ev
macro list
scalar list 

postutil clear
postfile mypost probY upper lower using simresults, replace 
noisily display "start"
set obs 10000 
while `a' <= 20  {

qui simqi, ev 
scalar probY= Pr
scalar upper = PrU
scalar lower = PrL
post mypost (probY) (upper) (lower)
scalar drop probY upper lower
local a = `a'+.5 /*the amount we will increase height by: .5in. */
local b = (`a'^2)
setx polity20 (`a') polity_square (`b')
display "." _c 
}
display ""

postclose mypost 


clear

use simresults 
range MV 0 20 41
replace MV = MV -10
sort MV

gen group = 1

format probY upper lower %9.2f

save plot1.dta, replace 

twoway rarea lower upper MV, color(gray*.5) fi(100) ///
		|| line probY MV,  clcolor(black) clpattern(solid) legend(off) ///
		ytitle(Predicted HRO Secretariat Count) xtitle(Polity) ///
		ylabel(.25(.25)1.25)
		


* Binomial Decomposition
clear
use "Replication data.dta"
replace polity20 = polity20-10

gen politydum_10 = 0
replace politydum_10=1 if polity20==-10
gen politydum_9=0
replace politydum_9=1 if polity20==-9
gen politydum_8=0
replace politydum_8=1 if polity20==-8
gen politydum_7=0
replace politydum_7=1 if polity20==-7
gen politydum_6=0
replace politydum_6=1 if polity20==-6
gen politydum_5=0
replace politydum_5=1 if polity20==-5
gen politydum_4=0
replace politydum_4=1 if polity20==-4
gen politydum_3=0
replace politydum_3=1 if polity20==-3
gen politydum_2=0
replace politydum_2=1 if polity20==-2
gen politydum_1=0
replace politydum_1=1 if polity20==-1
gen politydum0=0
replace politydum0=1 if polity20==0
gen politydum10=0
replace politydum10=1 if polity20==10
gen politydum9=0
replace politydum9=1 if polity20==9
gen politydum8=0
replace politydum8=1 if polity20==8
gen politydum7=0
replace politydum7=1 if polity20==7
gen politydum6=0
replace politydum6=1 if polity20==6
gen politydum5=0
replace politydum5=1 if polity20==5
gen politydum4=0
replace politydum4=1 if polity20==4
gen politydum3=0
replace politydum3=1 if polity20==3
gen politydum2=0
replace politydum2=1 if polity20==2
gen politydum1=0
replace politydum1=1 if polity20==1

estsimp nbreg F.hrosecloc_merge physint con_physint conphysXphys politydum_10-politydum_1 politydum10-politydum1 orgrights kof_ogi S_all latincarib durable lngdppercap lnpop civilconflict  NGOtargetGTDfilled dictHROngostateviolent  lnreport conhrosecloc lnhrfilled yr12-yr24 if western==0 & polity20~=.  , robust

setx mean //first set all to means, then modifiy where needed (below)
setx civilconflict 0
setx latincarib 0 
setx dictHROngostateviolent 0
setx (yr12-yr24) 0
setx yr15 1
setx (politydum_10-politydum_1 politydum10-politydum1) 0

postutil clear
postfile mypost2 probY upper lower using simresults2, replace
noisily display "start"
set obs 10000 

simqi, ev
scalar probY = Pr
scalar upper = PrU
scalar lower = PrL
post mypost2 (probY) (upper) (lower) 
scalar drop probY upper lower 

foreach var of varlist politydum_10-politydum_1 politydum10-politydum1 {
setx (politydum_10-politydum_1 politydum10-politydum1) 0
setx `var' 1
simqi, ev
scalar probY = Pr
scalar upper = PrU
scalar lower = PrL
post mypost2 (probY) (upper) (lower) 
scalar drop probY upper lower
display "." _c 
}
display ""

postclose mypost2 


clear

use simresults2 
gen MV = .
replace MV = 0 in 1
replace MV = -10 in 2
replace MV = -9 in 3
replace MV = -8 in 4
replace MV = -7 in 5
replace MV = -6 in 6
replace MV = -5 in 7
replace MV = -4 in 8
replace MV = -3 in 9
replace MV = -2 in 10
replace MV = -1 in 11
replace MV = 1 in 12
replace MV = 2 in 13
replace MV = 3 in 14
replace MV = 4 in 15
replace MV = 5 in 16
replace MV = 6 in 17
replace MV = 7 in 18
replace MV = 8 in 19
replace MV = 9 in 20
replace MV = 10 in 21

sort MV

gen group = 2

save plot2.dta, replace

twoway rarea lower upper MV, color(gray*.5) fi(100) ///
		|| line probY MV,  clcolor(black) clpattern(solid) legend(off) ///
		ytitle(Predicted HRO Secretariat Count) xtitle(Polity) ///
		ylabel(0(.5)2) xlab(-10(2)10) yline(0)


append using plot1
save plotmerge, replace 

clear
use plotmerge.dta
save plotmerge.dta, replace



/*

R Code for appendix figure. Same code can be modified to produce other graphs. 

library(ggplot2)
library(gridExtra)
library(foreign)

mydata <- read.dta(file="plotmerge.dta")
plot1 <- ggplot(mydata, aes(x=MV, group = group)) +
  geom_hline(aes(yintercept=0), size = .5, color = "black") +
  geom_line(aes(y=probY), alpha =1, show_guide=T) +
  geom_ribbon(aes(ymin = lower, ymax=upper), fill = "gray", alpha=.3) +
  theme_bw() +
  theme(legend.position="bottom", legend.title=element_blank()) +
  theme(text=element_text(size=16)) +
  labs(x = "Polity", y = "Predicted HRO Secretariat Count")  +
  scale_x_continuous(breaks=seq(-10, 10, 2), limits=c(-10, 10)) +
  scale_y_continuous(breaks=seq(0, 2.0, .5), limits = c(0, 2.05))

plot1
dev.off()
